import axios from 'axios'
import { Notify } from 'vant';
import utils from '@/utils/encode'
import { getToken } from '@/utils/auth'
import useStore from '@/store/piniaIndex';
import { Toast } from 'vant';

const CancelToken = axios.CancelToken;
const timeout = 20000
const WhiteApiErr = ['userSavePermissionByPhone','batchEnableDisable','batchPriceEnableDisable','getPushOrderInfo']
const service = axios.create({
  baseURL: process.env.VUE_APP_BASE_API,
  timeout: timeout // 默认请求超时时间
})
const timeoutWhite = ['/oil-finance/oilOrderInfo/importExcelOrder']

// 加密白名单
const encryptWhite = ['/oil-finance/oilOrderInfo/importExcelOrder']
let a = []
// request 拦截器
service.interceptors.request.use(
  config => {
    Toast.loading({
      message: '加载中...',
      forbidClick: true,
      duration:0
    });
    let source = CancelToken.source();
    config.cancelToken = source.token;
    if(a.includes(config.url)){
      source.cancel(`tooRapid`);
      return config
    }
    a.push(config.url)
    if ( timeoutWhite.includes(config.url)) {
      config.timeout = 0
    } else {
      config.timeout = timeout
    }
    const notEncrypt = config.notEncrypt
    config.headers['dataSources'] = 'WEB'
    let  token = getToken();
    console.log(getToken(),'getTokengetTokengetTokengetTokengetToken')
    if (token) {
      console.log(token,'tokentokentokentoken')
      config.headers['Authorization'] =  utils.decrypt(token,'Clco2uJjhZRgDHzl') ;
      console.log(config.headers,'Authorization')
    }
    const JSESSIONID = utils.uuid()
    config.headers['JSESSIONID'] = JSESSIONID
    config.headers['token'] = utils.bcrypt(JSESSIONID)
    const env = process.env.VUE_APP_ENV
    if (env === 'test') {
      console.log('这里是测试')
      // 测试环境，加密，打印参数
      // 设置jsessionid和token
      if (!notEncrypt && encryptWhite.indexOf(config.url) < 0) {
        const data = { // 用于存储加密
          params: '' // 加密后的密文
        }
        // 要加密
        console.log('请求路径', config.url, '参数加密前', config.data)
        data.params = utils.encrypt(JSON.stringify(config.data))
        config.data = data
      }
    }
    if (env === 'development') {
      console.log('这里是测试')
      // 测试环境,不加密,打印参数
      console.log('请求路径', config.url, '参数加密前', config.data)
    }

    if (env === 'production') {
      console.log('这里是生产')
      // 生产环境，加密，不输出任何东西
      // 设置jsessionid和token
      const JSESSIONID = utils.uuid()
      config.headers['JSESSIONID'] = JSESSIONID
      config.headers['token'] = utils.bcrypt(JSESSIONID)
      if (!notEncrypt && encryptWhite.indexOf(config.url) < 0) {
        const data = { // 用于存储加密
          params: '' // 加密后的密文
        }
        // 要加密
        data.params = utils.encrypt(JSON.stringify(config.data))
        config.data = data
      }
    }
    return config
  },
  error => {
    console.log(error.message,'req')
    return Promise.reject(error)
  }
)

// response 拦截器
service.interceptors.response.use(
  response => {
    Toast.clear()
   let urlIndex = a.indexOf(response.config.url)
    if(urlIndex!==-1){
      a.splice(urlIndex,1);
    }
    // 这里设置loading
    const res = response.data
    const env = process.env.VUE_APP_ENV
    if (response.headers['content-type'].indexOf('application/json') !== -1) {
      if (env === 'test') {
        // 测试环境，进行加密解密，打印路径和数据
        if (res.encrypt === 1) {
          // 加密的数据，需要解密
          console.log('请求路径', response.config.url, '返回结果解密前', res)
          const dataParam = JSON.parse(utils.decrypt(res.data))
          res.data = JSON.stringify(dataParam) === '{}' ? null : dataParam
          console.log('请求路径', response.config.url, '返回结果解密后', res)
          console.log('-------------------------------------------')
        } else {
          console.log('请求路径', response.config.url, '返回结果未加密', res)
          console.log('-------------------------------------------')
        }
      }
      if (env === 'production') {
        // 生产环境，进行加密解密，不输出日志
        if (res.encrypt === 1) {
          // 加密的数据，需要解密
          const dataParam = JSON.parse(utils.decrypt(res.data))
          res.data = JSON.stringify(dataParam) === '{}' ? null : dataParam
        }
      }
    } else {
      return res
    }

    // 50008: Illegal token; 50012: Other clients logged in; 50014: Token expired;
    if (res && res.code) {
      if (res.code === 42011) {
        // to re-login
        Notify({
          message: res.msg || '您的登录已失效，请重新登录',
          type: 'danger',
          duration: 5 * 1000
        })
        // let store = useStore();
        // store.clearToken()
        // store.dispatch('user/resetToken').then(() => {
        //   location.reload()
        // })
        // 排除自定义的车队返回结果状态码
      } else if (res.code !== 20000 && res.code !== 30001 && res.code !== 30002 && res.code !== 20001) {
        if(response.config?.white){
          return res
        }else{
          Notify({
            message: res.msg || '操作失败',
            type: 'danger',
            duration: 5 * 1000
          })
          return Promise.reject(new Error(res.message || '操作失败'))
        }
      } else {
        // Toast.success(res.msg)
        return res
      }
    }
  },
  (error) => {
    if(error.message=='tooRapid'){
    console.log(error,'res防抖拦截')
    Notify({
      message: '请求过于频繁！',
      type: 'warning',
      duration: 5 * 1000
    })
    }else{
      let urlIndex = a.indexOf(error.config.url)
      if(urlIndex!==-1){
        a.splice(urlIndex,1);
      }
      Notify({
        message: '操作失败！',
        type: 'danger',
        duration: 5 * 1000
      })
    }
    return Promise.reject(error)
  }
)

export default service
